%define major	0
%define libname	%mklibname %{name} %{major}
%define devname	%mklibname %{name} -d

# keep p11-kit-proxy.so from pulling in devel files
%global __devel_exclude_path %{_libdir}/p11-kit-proxy\.so

Name:		p11-kit
Summary:	Load and enumerate PKCS#11 modules
Version:	0.25.5
Release:	%mkrel 1
License:	Apache License
Group:		System/Libraries
Url:		https://p11-glue.freedesktop.org/p11-kit.html
Source0:	https://github.com/p11-glue/p11-kit/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:	https://github.com/p11-glue/p11-kit/releases/download/%{version}/%{name}-%{version}.tar.xz.sig
Patch0:		p11-kit-0.25.3-linking.patch
BuildRequires:	meson
BuildRequires:	pkgconfig(bash-completion)
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(libtasn1)
BuildRequires:	pkgconfig(libffi)
BuildRequires:	pkgconfig(libsystemd)
BuildRequires:	pkgconfig(gtk-doc)
BuildRequires:	gettext-devel
BuildRequires:	xsltproc

%description
Provides a way to load and enumerate PKCS#11 modules. Provides a standard
configuration setup for installing PKCS#11 modules in such a way that
they're discoverable.

Also solves problems with coordinating the use of PKCS#11 by different
components or libraries living in the same process.

%package -n	%{libname}
Summary:	Library and proxy module for properly loading and sharing PKCS#11 modules
Group:		System/Libraries
Requires:	%{name} = %{version}-%{release}

%description -n	%{libname}
Provides a way to load and enumerate PKCS#11 modules. Provides a standard
configuration setup for installing PKCS#11 modules in such a way that
they're discoverable.

Also solves problems with coordinating the use of PKCS#11 by different
components or libraries living in the same process.

%package -n	%{devname}
Summary:	Development files and headers for %{name}
Group:		Development/Other
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n	%{devname}
This package contains the development files and headers for %{name}.

%package	trust
Summary:	System trust module from %{name}
Requires:	%{name} = %{version}-%{release}
Conflicts:	%{_lib}p11-kit0 < 0.24.1-2

%description	trust
The %{name}-trust package contains a system trust PKCS#11 module which
contains certificate anchors and black lists.

%prep
%autosetup -p1

%build
%meson -Dgtk_doc=true \
       -Dman=true \
       -Dtrust_paths=%{_sysconfdir}/pki/ca-trust/source:%{_datadir}/pki/ca-trust-source \
%meson_build

%install
%meson_install

#dirs for configs etc
mkdir -p %{buildroot}%{_sysconfdir}/pkcs11/modules

# install the example config file as config file (mga #12696)
mv %{buildroot}%{_sysconfdir}/pkcs11/pkcs11.conf.example %{buildroot}%{_sysconfdir}/pkcs11/pkcs11.conf

%find_lang %{name}

# Disable for now as it fails on 32-bit and 64-bit
# Need more investigation and a fix
%check
#meson_test

# remove invalid empty config file installed by default until p11-kit-0.20.1-3 (mga #12696)
%pretrans -p <lua>

file = io.open("/etc/pkcs11/pkcs11.conf","r")

if (file) then
  size = file:seek("end")
  file:close()
  if (size == 0) then
    os.remove("/etc/pkcs11/pkcs11.conf")
  end
end

%files -f %{name}.lang
%doc build/p11-kit/pkcs11.conf.example
%{_bindir}/%{name}
%dir %{_sysconfdir}/pkcs11
%dir %{_sysconfdir}/pkcs11/modules
%config(noreplace) %{_sysconfdir}/pkcs11/pkcs11.conf
%dir %{_libdir}/pkcs11/
%dir %{_datadir}/p11-kit
%dir %{_datadir}/p11-kit/modules
%{_mandir}/man?/%{name}.*.*
%{_mandir}/man?/pkcs11.conf.*.*
%dir %{_libexecdir}/p11-kit/
%{_libexecdir}/p11-kit/p11-kit-remote
%{_libexecdir}/p11-kit/p11-kit-server
%{_userunitdir}/p11-kit-server.service
%{_userunitdir}/p11-kit-server.socket
%{_datadir}/bash-completion/completions/p11-kit

%files -n %{libname}
%doc AUTHORS NEWS
%{_libdir}/lib%{name}.so.%{major}{,.*}
%{_libdir}/p11-kit-proxy.so

%files -n %{devname}
%doc %{_datadir}/gtk-doc/html/%{name}
%{_includedir}/%{name}-1
%{_libdir}/libp11-kit.so
%{_libdir}/pkcs11/*.so
%{_libdir}/pkgconfig/%{name}-1.pc

%files trust
%{_bindir}/trust
%dir %{_libdir}/pkcs11
%{_libdir}/pkcs11/p11-kit-trust.so
%{_datadir}/p11-kit/modules/p11-kit-trust.module
%{_libexecdir}/p11-kit/trust-extract-compat
%{_datadir}/bash-completion/completions/trust
%{_mandir}/man?/trust.*.*


%changelog
* Thu Jul 04 2024 daviddavid <daviddavid> 0.25.5-1.mga10
+ Revision: 2079670
- new version: 0.25.5

* Fri Apr 05 2024 wally <wally> 0.25.3-3.mga10
+ Revision: 2054669
- basesystem rebuild for i686

* Sun Mar 03 2024 wally <wally> 0.25.3-2.mga10
+ Revision: 2047386
- add upstream patch to fix build with gcc >= 14

* Wed Nov 29 2023 daviddavid <daviddavid> 0.25.3-1.mga10
+ Revision: 2011144
- new version: 0.25.3

* Thu Jun 22 2023 wally <wally> 0.24.1-2.mga9
+ Revision: 1962818
- move p11-kit trust module config to p11-kit-trust pkg

* Tue Nov 15 2022 kekepower <kekepower> 0.24.1-1.mga9
+ Revision: 1907750
- Update to version 0.24.1

* Tue Mar 29 2022 umeabot <umeabot> 0.24.0-2.mga9
+ Revision: 1831929
- Mageia 9 Mass Rebuild

* Sun Aug 08 2021 luigiwalser <luigiwalser> 0.24.0-1.mga9
+ Revision: 1740474
- 0.24.0
- remove upstreamed patch 1

* Thu Aug 05 2021 luigiwalser <luigiwalser> 0.23.22-4.mga9
+ Revision: 1739661
- rebuild for libffi
+ wally <wally>
- own /usr/libexec/p11-kit directory

* Tue Jun 01 2021 luigiwalser <luigiwalser> 0.23.22-3.mga9
+ Revision: 1729098
- add patch from fedora to suppress intentional memleak in getprogname emulation (rhbz#1905581)

* Sat Jan 09 2021 luigiwalser <luigiwalser> 0.23.22-2.mga8
+ Revision: 1670179
- more correct way to filter devel requires from .so file in lib package

* Wed Dec 16 2020 luigiwalser <luigiwalser> 0.23.22-1.mga8
+ Revision: 1658081
- 0.23.22

* Mon Sep 07 2020 luigiwalser <luigiwalser> 0.23.21-1.mga8
+ Revision: 1623356
- 0.23.21
- rediff linking patch

* Thu Jun 11 2020 tv <tv> 0.23.20-8.mga8
+ Revision: 1592584
- use new rootcerts paths
- use %%autosetup

* Thu Jun 11 2020 joequant <joequant> 0.23.20-7.mga8
+ Revision: 1592278
- rebuild against new ffi

* Sun Jun 07 2020 joequant <joequant> 0.23.20-6.mga8
+ Revision: 1590859
- remove devel autorequires from lib package

* Fri Jun 05 2020 luigiwalser <luigiwalser> 0.23.20-5.mga8
+ Revision: 1590590
- add trust_paths argument to build

* Thu Jun 04 2020 luigiwalser <luigiwalser> 0.23.20-4.mga8
+ Revision: 1590433
- move p11-kit-proxy.so to the library package where it belongs

* Wed Mar 18 2020 daviddavid <daviddavid> 0.23.20-3.mga8
+ Revision: 1557750
- switch to meson build system

* Thu Feb 20 2020 umeabot <umeabot> 0.23.20-2.mga8
+ Revision: 1547381
- Mageia 8 Mass Rebuild

* Sun Feb 09 2020 luigiwalser <luigiwalser> 0.23.20-1.mga8
+ Revision: 1488092
- 0.23.20

* Thu Jan 23 2020 daviddavid <daviddavid> 0.23.19-1.mga8
+ Revision: 1482510
- new version: 0.23.19
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Sep 30 2019 daviddavid <daviddavid> 0.23.18.1-1.mga8
+ Revision: 1448477
- new version: 0.23.18.1

* Fri Aug 30 2019 daviddavid <daviddavid> 0.23.16.1-2.mga8
+ Revision: 1435235
- rebuild for new gcc 9

* Sat Jul 06 2019 daviddavid <daviddavid> 0.23.16.1-1.mga8
+ Revision: 1418984
- new version: 0.23.16.1

* Mon Jan 21 2019 daviddavid <daviddavid> 0.23.15-1.mga7
+ Revision: 1358775
- new version: 0.23.15

* Sat Nov 10 2018 daviddavid <daviddavid> 0.23.14-1.mga7
+ Revision: 1329351
- new version: 0.23.14

* Sun Sep 23 2018 umeabot <umeabot> 0.23.13-2.mga7
+ Revision: 1300082
- Mageia 7 Mass Rebuild

* Fri Aug 17 2018 daviddavid <daviddavid> 0.23.13-1.mga7
+ Revision: 1252088
- new version: 0.23.13

* Tue Apr 17 2018 kekepower <kekepower> 0.23.10-1.mga7
+ Revision: 1219733
- BR gettext-devel
- Update to version 0.23.10

* Fri May 13 2016 daviddavid <daviddavid> 0.23.2-2.mga6
+ Revision: 1015053
- use std build macros; prevent commented out macros to break build

* Mon Jan 11 2016 luigiwalser <luigiwalser> 0.23.2-1.mga6
+ Revision: 921782
- 0.23.2 (needed for gnutls 3.4)

* Fri Aug 21 2015 tmb <tmb> 0.22.1-2.mga6
+ Revision: 867671
- rebuild for new gcc

* Sun Jun 21 2015 ovitters <ovitters> 0.22.1-1.mga6
+ Revision: 837842
- new version 0.22.1

* Wed Oct 15 2014 umeabot <umeabot> 0.20.6-6.mga5
+ Revision: 748305
- Second Mageia 5 Mass Rebuild

* Thu Oct 09 2014 tv <tv> 0.20.6-5.mga5
+ Revision: 737755
- keep %%pretrans but use lua for scriptlet

* Thu Oct 09 2014 tv <tv> 0.20.6-4.mga5
+ Revision: 737743
- do not use %%pretrans when %%pre is enough;
  this add a "interp,pretrans: /bin/sh" dep which breaks installer first transaction

* Fri Oct 03 2014 tmb <tmb> 0.20.6-3.mga5
+ Revision: 736547
- rebuild for /bin/sh dep

* Tue Sep 16 2014 umeabot <umeabot> 0.20.6-2.mga5
+ Revision: 683300
- Mageia 5 Mass Rebuild

* Tue Sep 09 2014 luigiwalser <luigiwalser> 0.20.6-1.mga5
+ Revision: 674245
- 0.20.6

* Fri Sep 05 2014 luigiwalser <luigiwalser> 0.20.5-1.mga5
+ Revision: 672267
- 0.20.5

* Sat Aug 16 2014 luigiwalser <luigiwalser> 0.20.4-1.mga5
+ Revision: 664087
- 0.20.4

* Thu Jul 10 2014 luigiwalser <luigiwalser> 0.20.3-1.mga5
+ Revision: 651145
- 0.20.3
- remove upstreamed patch

* Sat Feb 15 2014 luigiwalser <luigiwalser> 0.20.2-1.mga5
+ Revision: 591480
- 0.20.2
- Own the %%{_libdir}/pkcs11 dir in -trust

* Wed Feb 12 2014 lmenut <lmenut> 0.20.1-6.mga5
+ Revision: 589908
- remove requires to rpm-helper after posttrans removal

* Tue Feb 11 2014 lmenut <lmenut> 0.20.1-5.mga5
+ Revision: 589572
- install valid pkcs11.conf (mga#12696)
  + remove invalid empty config file in pretrans
  + install uptream example config as default config

* Mon Feb 10 2014 pterjan <pterjan> 0.20.1-4.mga5
+ Revision: 587833
- Fix handling of mmap failure

* Tue Oct 29 2013 tv <tv> 0.20.1-3.mga4
+ Revision: 547769
- move rpm-helper %%post in %%posttrans (trying to fix install deps loop errors)

* Sat Oct 19 2013 umeabot <umeabot> 0.20.1-2.mga4
+ Revision: 535052
- Mageia 4 Mass Rebuild

* Tue Sep 17 2013 dams <dams> 0.20.1-1.mga4
+ Revision: 480854
- disable %%check for now as it fails in 32-bit
- new version 0.20.1
- enable man page

* Tue Jul 23 2013 luigiwalser <luigiwalser> 0.18.5-1.mga4
+ Revision: 457503
- 0.18.5

* Sun May 26 2013 blino <blino> 0.18.2-1.mga4
+ Revision: 428249
- buildrequire pkgconfig(libtasn1)
- package trust module in a subpackage
- 0.18.2

* Sun Jan 13 2013 umeabot <umeabot> 0.14-2.mga3
+ Revision: 362317
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Sep 16 2012 fwang <fwang> 0.14-1.mga3
+ Revision: 294398
- new version 0.14

* Mon Jul 16 2012 wally <wally> 0.13-1.mga3
+ Revision: 271336
- new version 0.13

* Tue May 29 2012 dams <dams> 0.12-1.mga3
+ Revision: 249107
- new version 0.12
- add a 'requires(post)' on 'rpm-helper'

* Fri Feb 10 2012 wally <wally> 0.11-1.mga2
+ Revision: 206898
- new version 0.11

* Tue Jan 03 2012 wally <wally> 0.10-1.mga2
+ Revision: 189984
- new version 0.10

* Thu Nov 17 2011 wally <wally> 0.9-1.mga2
+ Revision: 168377
- new version 0.9

* Thu Oct 27 2011 wally <wally> 0.8-1.mga2
+ Revision: 158797
- new version 0.8

* Wed Sep 28 2011 wally <wally> 0.7-1.mga2
+ Revision: 149934
- new version 0.7

* Fri Sep 16 2011 wally <wally> 0.6-1.mga2
+ Revision: 144292
- new version 0.6

* Mon Sep 05 2011 wally <wally> 0.5-1.mga2
+ Revision: 138880
- new version 0.5
- new version 0.4
- make devel package require the lib one
- fix requires
- imported package p11-kit
+ fwang <fwang>
- new version 0.3

